==> haskell-ixset-typed-0.5.1.0-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ixset-typed
version:              0.5.1.0
visibility:           public
id:                   ixset-typed-0.5.1.0-9ttLyWS8ebJ2P7FHjI2qDM
key:                  ixset-typed-0.5.1.0-9ttLyWS8ebJ2P7FHjI2qDM
license:              BSD-3-Clause
maintainer:           Andres Löh <andres@well-typed.com>
author:               Andres Löh, Happstack team, HAppS LLC
synopsis:             Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.

    Sets can be created, modified, and queried in various ways.

    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.

    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.

category:             Data Structures
abi:                  c6fcda80eb8d880840d5e07984512ce1
exposed:              True
exposed-modules:      Data.IxSet.Typed Data.IxSet.Typed.Ix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ixset-typed-0.5.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ixset-typed-0.5.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ixset-typed-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ixset-typed
hs-libraries:         HSixset-typed-0.5.1.0-9ttLyWS8ebJ2P7FHjI2qDM
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    safecopy-0.10.4.2-A7auuFQhsGnCqkhFFL5Kr1
    syb-0.7.2.4-7JOtjKcEmcW20UWUNnrGCM template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html:         /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ixset-typed-0.5.1.0-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ixset-typed
version:              0.5.1.0
visibility:           public
id:                   ixset-typed-0.5.1.0-DKh6uGHoO5ZHSHkFIILorG
key:                  ixset-typed-0.5.1.0-DKh6uGHoO5ZHSHkFIILorG
license:              BSD-3-Clause
maintainer:           Andres Löh <andres@well-typed.com>
author:               Andres Löh, Happstack team, HAppS LLC
synopsis:             Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.

    Sets can be created, modified, and queried in various ways.

    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.

    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.

category:             Data Structures
abi:                  e6805b94ca2ded7f2e587daa63881e01
exposed:              True
exposed-modules:      Data.IxSet.Typed Data.IxSet.Typed.Ix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ixset-typed-0.5.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ixset-typed-0.5.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ixset-typed-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ixset-typed
hs-libraries:         HSixset-typed-0.5.1.0-DKh6uGHoO5ZHSHkFIILorG
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    safecopy-0.10.4.2-Ik8LwkOKffvJuBUc9O5nTf
    syb-0.7.2.4-7JOtjKcEmcW20UWUNnrGCM template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html:         /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
